Merge "examples: rename veyron to v23 or vanadium Change-Id: I378d4bf60e55454697634cca427f2d5e8aede8cc"
diff --git a/examples/rps/service.vdl b/examples/rps/service.vdl
index 708cb85..9f09af9 100644
--- a/examples/rps/service.vdl
+++ b/examples/rps/service.vdl
@@ -1,4 +1,4 @@
-// Package rps is an example of veyron service for playing the game of
+// Package rps is an example of vanadium service for playing the game of
 // Rock-Paper-Scissors. (http://en.wikipedia.org/wiki/Rock-paper-scissors)
 //
 // There are three different roles in the game:
diff --git a/examples/rps/service.vdl.go b/examples/rps/service.vdl.go
index b3f6829..1cb6535 100644
--- a/examples/rps/service.vdl.go
+++ b/examples/rps/service.vdl.go
@@ -1,7 +1,7 @@
 // This file was auto-generated by the veyron vdl tool.
 // Source: service.vdl
 
-// Package rps is an example of veyron service for playing the game of
+// Package rps is an example of vanadium service for playing the game of
 // Rock-Paper-Scissors. (http://en.wikipedia.org/wiki/Rock-paper-scissors)
 //
 // There are three different roles in the game:
diff --git a/examples/tunnel/vsh/main.go b/examples/tunnel/vsh/main.go
index e37f0df..ef4a0ed 100644
--- a/examples/tunnel/vsh/main.go
+++ b/examples/tunnel/vsh/main.go
@@ -51,15 +51,15 @@
 through the tunneld service. The flag value is localaddr,remoteaddr. E.g.
   -L :14141,www.google.com:80
 
 %s can't be used directly with tools like rsync because veyron object names
 don't look like traditional hostnames, which rsync doesn't understand. For
 compatibility with such tools, %s has a special feature that allows passing the
-veyron object name via the VSH_NAME environment variable.
+vanadium object name via the VSH_NAME environment variable.
 
-  $ VSH_NAME=<object name> rsync -avh -e %s /foo/* veyron:/foo/
+  $ VSH_NAME=<object name> rsync -avh -e %s /foo/* v23:/foo/
 
-In this example, the "veyron" host will be substituted with $VSH_NAME by %s
-and rsync will work as expected.
+In this example, the "v23" host will be substituted with $VSH_NAME by %s and
+rsync will work as expected.
 
 Full flags:
 `, os.Args[0], bname, bname, bname, bname, os.Args[0], bname)
@@ -162,9 +162,9 @@
 	// don't look like traditional hostnames, tools that work with rsh and
 	// ssh can't work directly with vsh. This trick makes the following
 	// possible:
-	//   $ VSH_NAME=<object name> rsync -avh -e vsh /foo/* veyron:/foo/
-	// The "veyron" host will be substituted with <object name>.
-	if envName := os.Getenv("VSH_NAME"); len(envName) > 0 && name == "veyron" {
+	//   $ VSH_NAME=<object name> rsync -avh -e vsh /foo/* v23:/foo/
+	// The "v23" host will be substituted with <object name>.
+	if envName := os.Getenv("VSH_NAME"); len(envName) > 0 && name == "v23" {
 		name = envName
 	}
 	cmd := strings.Join(args, " ")
@@ -51,15 +51,15 @@
   -L :14141,www.google.com:80
 
-%s can't be used directly with tools like rsync because veyron object names
+%s can't be used directly with tools like rsync because vanadium object names
 don't look like traditional hostnames, which rsync doesn't understand. For
 compatibility with such tools, %s has a special feature that allows passing the